emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master 462dbc1: ; Fix typos


From: Stefan Kangas
Subject: master 462dbc1: ; Fix typos
Date: Mon, 21 Sep 2020 08:53:13 -0400 (EDT)

branch: master
commit 462dbc1cb2c59eaca9c9344636b8af29462370a0
Author: Stefan Kangas <stefan@marxist.se>
Commit: Stefan Kangas <stefan@marxist.se>

    ; Fix typos
---
 admin/unidata/unidata-gen.el                              |  4 ++--
 lib-src/ebrowse.c                                         |  2 +-
 lisp/cedet/semantic/bovine/el.el                          |  2 +-
 lisp/cedet/semantic/db-find.el                            |  4 ++--
 lisp/cedet/semantic/db.el                                 |  4 ++--
 lisp/cedet/semantic/lex.el                                |  2 +-
 lisp/composite.el                                         |  2 +-
 lisp/descr-text.el                                        |  2 +-
 lisp/emacs-lisp/eieio.el                                  |  2 +-
 lisp/emacs-lisp/eldoc.el                                  |  4 ++--
 lisp/emacs-lisp/pcase.el                                  |  4 ++--
 lisp/emacs-lisp/re-builder.el                             |  2 +-
 lisp/epa.el                                               |  2 +-
 lisp/erc/erc-networks.el                                  |  2 +-
 lisp/gnus/gnus-agent.el                                   |  2 +-
 lisp/gnus/mm-view.el                                      |  2 +-
 lisp/gnus/nndiary.el                                      |  2 +-
 lisp/gnus/nnir.el                                         |  2 +-
 lisp/htmlfontify.el                                       |  2 +-
 lisp/international/ucs-normalize.el                       |  2 +-
 lisp/jsonrpc.el                                           |  4 ++--
 lisp/kmacro.el                                            |  2 +-
 lisp/language/korea-util.el                               |  4 ++--
 lisp/mh-e/mh-limit.el                                     |  4 ++--
 lisp/mh-e/mh-speed.el                                     |  2 +-
 lisp/net/tramp.el                                         |  4 ++--
 lisp/play/5x5.el                                          |  2 +-
 lisp/progmodes/cc-engine.el                               |  8 ++++----
 lisp/progmodes/cperl-mode.el                              |  4 ++--
 lisp/progmodes/elisp-mode.el                              |  2 +-
 lisp/progmodes/etags.el                                   |  2 +-
 lisp/progmodes/flymake.el                                 |  8 ++++----
 lisp/progmodes/gdb-mi.el                                  |  2 +-
 lisp/progmodes/hideif.el                                  |  8 ++++----
 lisp/progmodes/make-mode.el                               |  2 +-
 lisp/progmodes/project.el                                 |  4 ++--
 lisp/progmodes/python.el                                  |  8 ++++----
 lisp/progmodes/verilog-mode.el                            |  2 +-
 lisp/replace.el                                           |  2 +-
 lisp/ses.el                                               |  4 ++--
 lisp/so-long.el                                           |  2 +-
 lisp/subr.el                                              |  2 +-
 lisp/wid-browse.el                                        |  2 +-
 lisp/xwidget.el                                           |  4 ++--
 src/dispextern.h                                          |  2 +-
 src/keyboard.c                                            |  4 ++--
 src/nsxwidget.m                                           |  2 +-
 src/pdumper.c                                             |  4 ++--
 src/term.c                                                |  2 +-
 src/w32fns.c                                              | 10 +++++-----
 src/w32heap.c                                             |  2 +-
 src/w32menu.c                                             |  2 +-
 src/w32term.c                                             |  2 +-
 src/w32term.h                                             |  2 +-
 src/xdisp.c                                               |  6 +++---
 src/xfns.c                                                |  2 +-
 src/xterm.h                                               |  2 +-
 test/lisp/dired-aux-tests.el                              |  2 +-
 test/lisp/emacs-lisp/faceup-resources/faceup-test-mode.el |  2 +-
 test/lisp/emacs-lisp/lisp-mode-tests.el                   |  2 +-
 test/lisp/gnus/mml-sec-tests.el                           |  2 +-
 test/lisp/jsonrpc-tests.el                                |  2 +-
 test/manual/etags/c-src/emacs/src/keyboard.c              |  2 +-
 test/manual/etags/y-src/parse.c                           |  2 +-
 64 files changed, 97 insertions(+), 97 deletions(-)

diff --git a/admin/unidata/unidata-gen.el b/admin/unidata/unidata-gen.el
index 73453cb..510bb79 100644
--- a/admin/unidata/unidata-gen.el
+++ b/admin/unidata/unidata-gen.el
@@ -77,7 +77,7 @@
 ;;     2nd: function to call to get a property value,
 ;;          or an index number of C function to decode the value,
 ;;          or nil if the value can be directly got from the table.
-;;     3nd: function to call to put a property value,
+;;     3rd: function to call to put a property value,
 ;;          or an index number of C function to encode the value,
 ;;          or nil if the value can be directly stored in the table.
 ;;     4th: function to call to get a description of a property value, or nil
@@ -1177,7 +1177,7 @@ Property value is a symbol `o' (Open), `c' (Close), or 
`n' (None)."
 
 (defun unidata-describe-general-category (val)
   (cdr (assq val
-            '((nil . "Uknown")
+            '((nil . "Unknown")
               (Lu . "Letter, Uppercase")
               (Ll . "Letter, Lowercase")
               (Lt . "Letter, Titlecase")
diff --git a/lib-src/ebrowse.c b/lib-src/ebrowse.c
index 70eb22b..7d0650a 100644
--- a/lib-src/ebrowse.c
+++ b/lib-src/ebrowse.c
@@ -1875,7 +1875,7 @@ yylex (void)
 
 
 /* Actually local to matching_regexp.  These variables must be in
-   global scope for the case that `static' get's defined away.  */
+   global scope for the case that `static' gets defined away.  */
 
 static char *matching_regexp_buffer, *matching_regexp_end_buf;
 
diff --git a/lisp/cedet/semantic/bovine/el.el b/lisp/cedet/semantic/bovine/el.el
index 822ec17..bbed1d9 100644
--- a/lisp/cedet/semantic/bovine/el.el
+++ b/lisp/cedet/semantic/bovine/el.el
@@ -649,7 +649,7 @@ define-mode-overload\\)\
                 ))
        (when fun
          ;; Do not return FUN IFF the cursor is on FUN.
-         ;; Huh?  Thats because if cursor is on fun, it is
+         ;; Huh?  That's because if cursor is on fun, it is
          ;; the current symbol, and not the current function.
          (if (save-excursion
                (condition-case nil
diff --git a/lisp/cedet/semantic/db-find.el b/lisp/cedet/semantic/db-find.el
index 510f931..86ccf28 100644
--- a/lisp/cedet/semantic/db-find.el
+++ b/lisp/cedet/semantic/db-find.el
@@ -1245,7 +1245,7 @@ See `semanticdb-find-translate-path' for details on PATH.
 The argument BRUTISH will be set so that searching includes all tables
 in the current project.
 FIND-FILE-MATCH indicates that any time a match is found, the file
-associated wit that tag should be loaded into a buffer."
+associated with that tag should be loaded into a buffer."
   (semanticdb-find-tags-collector
    (lambda (table tags)
      (semanticdb-deep-find-tags-by-name-method table name tags))
@@ -1257,7 +1257,7 @@ See `semanticdb-find-translate-path' for details on PATH.
 The argument BRUTISH will be set so that searching includes all tables
 in the current project.
 FIND-FILE-MATCH indicates that any time a match is found, the file
-associated wit that tag should be loaded into a buffer."
+associated with that tag should be loaded into a buffer."
   (semanticdb-find-tags-collector
    (lambda (table tags)
      (semanticdb-deep-find-tags-for-completion-method table prefix tags))
diff --git a/lisp/cedet/semantic/db.el b/lisp/cedet/semantic/db.el
index aaf43a1..60a65b1 100644
--- a/lisp/cedet/semantic/db.el
+++ b/lisp/cedet/semantic/db.el
@@ -89,7 +89,7 @@ same major mode as the current buffer.")
         :documentation "The tags belonging to this table.")
    (db-refs :initform nil
            :documentation
-           "List of `semanticdb-table' objects refering to this one.
+           "List of `semanticdb-table' objects referring to this one.
 These aren't saved, but are instead recalculated after load.
 See the file semanticdb-ref.el for how this slot is used.")
    (index :type semanticdb-abstract-search-index
@@ -764,7 +764,7 @@ If a particular major mode wants to search any mode, put the
 Do not set the value of this variable permanently.")
 
 (defmacro semanticdb-with-match-any-mode (&rest body)
-  "A Semanticdb search occurring withing BODY will search tags in all modes.
+  "A Semanticdb search occurring within BODY will search tags in all modes.
 This temporarily sets `semanticdb-match-any-mode' while executing BODY."
   (declare (indent 0) (debug t))
   `(let ((semanticdb-match-any-mode t))
diff --git a/lisp/cedet/semantic/lex.el b/lisp/cedet/semantic/lex.el
index 3e090c0..799aa45 100644
--- a/lisp/cedet/semantic/lex.el
+++ b/lisp/cedet/semantic/lex.el
@@ -1069,7 +1069,7 @@ Only in effect if `debug-on-error' is also non-nil."
   "For SYNTAX, execute FORMS with protection for unterminated syntax.
 If FORMS throws an error, treat this as a syntax problem, and
 execute the unterminated syntax code.  FORMS should return a position.
-Irregardless of an error, the cursor should be moved to the end of
+Regardless of an error, the cursor should be moved to the end of
 the desired syntax, and a position returned.
 If `debug-on-error' is set, errors are not caught, so that you can
 debug them.
diff --git a/lisp/composite.el b/lisp/composite.el
index 77c5cd8..47d91c5 100644
--- a/lisp/composite.el
+++ b/lisp/composite.el
@@ -660,7 +660,7 @@ All non-spacing characters have this function in
                    ;; align it at the center of the glyph of the
                    ;; enclosing mark hoping that the enclosing mark
                    ;; is big enough.  We also have to adjust the
-                   ;; x-offset and width of the mark ifself properly
+                   ;; x-offset and width of the mark itself properly
                    ;; depending on how the glyph is designed.
 
                    ;; (non-spacing or not).  For instance, when we
diff --git a/lisp/descr-text.el b/lisp/descr-text.el
index d6da428..9305664 100644
--- a/lisp/descr-text.el
+++ b/lisp/descr-text.el
@@ -953,7 +953,7 @@ This function can be used as a value of
       ;; exclusively, we could call the (now unused) argument
       ;; _CALLBACK with hints on how to shorten the string if needed,
       ;; or with multiple usable strings which ElDoc picks according
-      ;; to its space contraints.
+      ;; to its space constraints.
       (describe-char-eldoc--format
        ch
        (unless (eq eldoc-echo-area-use-multiline-p t)
diff --git a/lisp/emacs-lisp/eieio.el b/lisp/emacs-lisp/eieio.el
index b75410e..810affa 100644
--- a/lisp/emacs-lisp/eieio.el
+++ b/lisp/emacs-lisp/eieio.el
@@ -875,7 +875,7 @@ this object."
     ;; Now output readable lisp to recreate this object
     ;; It should look like this:
     ;; (<constructor> <name> <slot> <slot> ... )
-    ;; Each slot's slot is writen using its :writer.
+    ;; Each slot's slot is written using its :writer.
     (when eieio-print-indentation
       (princ (make-string (* eieio-print-depth 2) ? )))
     (princ "(")
diff --git a/lisp/emacs-lisp/eldoc.el b/lisp/emacs-lisp/eldoc.el
index f876805..8fc8db6 100644
--- a/lisp/emacs-lisp/eldoc.el
+++ b/lisp/emacs-lisp/eldoc.el
@@ -421,7 +421,7 @@ pairs of the form (:KEY VALUE :KEY2 VALUE2...).  KEY can be:
 
 * `:thing', VALUE is a short string or symbol designating what is
   being reported on.  The documentation display engine can elect
-  to remove this information depending on space contraints;
+  to remove this information depending on space constraints;
 
 * `:face', VALUE is a symbol designating a face to use when
   displaying `:thing''s value.
@@ -719,7 +719,7 @@ Other third-party strategy functions do not use
 produce callbacks to feed to `eldoc-documentation-function' and
 should endeavour to display the docstrings eventually produced."
   (let* (;; How many callbacks have been created by the strategy
-         ;; fucntion and passed to elements of
+         ;; function and passed to elements of
          ;; `eldoc-documentation-functions'.
          (howmany 0)
          ;; How many calls to callbacks we're still waiting on.  Used
diff --git a/lisp/emacs-lisp/pcase.el b/lisp/emacs-lisp/pcase.el
index a8ce232..09c48d0 100644
--- a/lisp/emacs-lisp/pcase.el
+++ b/lisp/emacs-lisp/pcase.el
@@ -594,7 +594,7 @@ MATCH is the pattern that needs to be matched, of the form:
                    ((null (cdr else-alts)) (car else-alts))
                    (t (cons (car match) (nreverse else-alts)))))))
     ((memq match '(:pcase--succeed :pcase--fail)) (cons match match))
-    (t (error "Uknown MATCH %s" match))))
+    (t (error "Unknown MATCH %s" match))))
 
 (defun pcase--split-rest (sym splitter rest)
   (let ((then-rest '())
@@ -725,7 +725,7 @@ MATCH is the pattern that needs to be matched, of the form:
                   (pcase--app-subst-match match sym fun nsym))
                 (cdr match))))
    ((memq match '(:pcase--succeed :pcase--fail)) match)
-   (t (error "Uknown MATCH %s" match))))
+   (t (error "Unknown MATCH %s" match))))
 
 (defun pcase--app-subst-rest (rest sym fun nsym)
   (mapcar (lambda (branch)
diff --git a/lisp/emacs-lisp/re-builder.el b/lisp/emacs-lisp/re-builder.el
index 0672f60..fbcd7b8 100644
--- a/lisp/emacs-lisp/re-builder.el
+++ b/lisp/emacs-lisp/re-builder.el
@@ -96,7 +96,7 @@
 ;;    out.
 
 ;; Q: But how can I then make out the sub-expressions?
-;; A: Thats where the `sub-expression mode' comes in.  In it only the
+;; A: That's where the `sub-expression mode' comes in.  In it only the
 ;;    digit keys are assigned to perform an update that will flash the
 ;;    corresponding subexp only.
 
diff --git a/lisp/epa.el b/lisp/epa.el
index b065887..609ac5d 100644
--- a/lisp/epa.el
+++ b/lisp/epa.el
@@ -400,7 +400,7 @@ DOC is documentation text to insert at the start."
 e  expired key.  n  never trust.  m  trust marginally.  u  trust ultimately.
 f  trust fully (keys you have signed, usually).
 q  trust status questionable.  -  trust status unspecified.
- See GPG documentaion for more explanation.
+ See GPG documentation for more explanation.
 \n"))
 
 ;;;###autoload
diff --git a/lisp/erc/erc-networks.el b/lisp/erc/erc-networks.el
index 8551cdd..309a788 100644
--- a/lisp/erc/erc-networks.el
+++ b/lisp/erc/erc-networks.el
@@ -152,7 +152,7 @@
   ("EFnet: EU, PL, Warszawa" EFnet "irc.efnet.pl" 6667)
   ("EFnet: EU, RU, Moscow" EFnet "irc.rt.ru" ((6661 6669)))
   ("EFnet: EU, SE, Dalarna" EFnet "irc.du.se" ((6666 6669)))
-  ("EFnet: EU, SE, Gothenberg" EFnet "irc.hemmet.chalmers.se" ((6666 7000)))
+  ("EFnet: EU, SE, Gothenburg" EFnet "irc.hemmet.chalmers.se" ((6666 7000)))
   ("EFnet: EU, SE, Sweden" EFnet "irc.light.se" 6667)
   ("EFnet: EU, UK, London (carrier)" EFnet "irc.carrier1.net.uk" ((6666 6669)))
   ("EFnet: EU, UK, London (demon)" EFnet "efnet.demon.co.uk" ((6665 6669)))
diff --git a/lisp/gnus/gnus-agent.el b/lisp/gnus/gnus-agent.el
index d7388d4..f748996 100644
--- a/lisp/gnus/gnus-agent.el
+++ b/lisp/gnus/gnus-agent.el
@@ -1304,7 +1304,7 @@ downloaded into the agent."
           ;; gnus doesn't waste resources trying to fetch them.
 
           ;; NOTE: I don't do this for smaller gaps (< 100) as I don't
-          ;; want to modify the local file everytime someone restarts
+          ;; want to modify the local file every time someone restarts
           ;; gnus.  The small gap will cause a tiny performance hit
           ;; when gnus tries, and fails, to retrieve the articles.
           ;; Still that should be smaller than opening a buffer,
diff --git a/lisp/gnus/mm-view.el b/lisp/gnus/mm-view.el
index cb39ffe..ca61001 100644
--- a/lisp/gnus/mm-view.el
+++ b/lisp/gnus/mm-view.el
@@ -546,7 +546,7 @@ If MODE is not set, try to find mode automatically."
   (mm-display-inline-fontify handle 'shell-script-mode))
 
 (defun mm-display-javascript-inline (handle)
-  "Show JavsScript code from HANDLE inline."
+  "Show JavaScript code from HANDLE inline."
   (mm-display-inline-fontify handle 'javascript-mode))
 
 ;;      id-signedData OBJECT IDENTIFIER ::= { iso(1) member-body(2)
diff --git a/lisp/gnus/nndiary.el b/lisp/gnus/nndiary.el
index 7894285..a43eee4 100644
--- a/lisp/gnus/nndiary.el
+++ b/lisp/gnus/nndiary.el
@@ -1425,7 +1425,7 @@ all.  This may very well take some time.")
        (pop years)))
     (if years
        ;; Because we might not be limited in years, we must guard against
-       ;; infinite loops. Appart from cases like Feb 31, there are probably
+       ;; infinite loops. Apart from cases like Feb 31, there are probably
        ;; other ones, (no monday XXX 2nd etc). I don't know any algorithm to
        ;; decide this, so I assume that if we reach 10 years later, the
        ;; schedule is undecidable.
diff --git a/lisp/gnus/nnir.el b/lisp/gnus/nnir.el
index 168c994..20f82e5 100644
--- a/lisp/gnus/nnir.el
+++ b/lisp/gnus/nnir.el
@@ -211,7 +211,7 @@ By default this is the name of an email header field.")
   "Search groups in Gnus with assorted search engines."
   :group 'gnus)
 
-(make-obsolete-variable 'nnir-summary-line-format "The formating
+(make-obsolete-variable 'nnir-summary-line-format "The formatting
 specs previously unique to this variable may now be set in
 'gnus-summary-line-format." "28.1")
 
diff --git a/lisp/htmlfontify.el b/lisp/htmlfontify.el
index 4d65397..ed2cd26 100644
--- a/lisp/htmlfontify.el
+++ b/lisp/htmlfontify.el
@@ -1034,7 +1034,7 @@ then the specification is returned unchanged."
    ((facep fn)
     (hfy-face-attr-for-class fn hfy-display-class))
    ;; FIXME: is this necessary? Faces can be symbols, but
-   ;; not symbols refering to other symbols?
+   ;; not symbols referring to other symbols?
    ((and (symbolp fn)
          (facep (symbol-value fn)))
     (hfy-face-attr-for-class
diff --git a/lisp/international/ucs-normalize.el 
b/lisp/international/ucs-normalize.el
index b703d3d..6b7419f 100644
--- a/lisp/international/ucs-normalize.el
+++ b/lisp/international/ucs-normalize.el
@@ -98,7 +98,7 @@
 ;;
 ;; D. Sorting and Composition  of Smaller Blocks 
(`ucs-normalize-block-compose-chars')
 ;;
-;;    The block will be split to multiple samller blocks by starter
+;;    The block will be split to multiple smaller blocks by starter
 ;;    characters.  Each block is sorted, and composed if necessary.
 ;;
 ;; E. Composition of Entire Block (`ucs-normalize-compose-chars')
diff --git a/lisp/jsonrpc.el b/lisp/jsonrpc.el
index 2d50df7..b319bf6 100644
--- a/lisp/jsonrpc.el
+++ b/lisp/jsonrpc.el
@@ -274,7 +274,7 @@ error of type `jsonrpc-error'.
 DEFERRED is passed to `jsonrpc-async-request', which see.
 
 If CANCEL-ON-INPUT is non-nil and the user inputs something while
-the functino is waiting, then it exits immediately, returning
+the function is waiting, then it exits immediately, returning
 CANCEL-ON-INPUT-RETVAL.  Any future replies (normal or error) are
 ignored."
   (let* ((tag (cl-gensym "jsonrpc-request-catch-tag")) id-and-timer
@@ -336,7 +336,7 @@ ignored."
   "Time in seconds before timing out a JSONRPC request.")
 
 
-;;; Specfic to `jsonrpc-process-connection'
+;;; Specific to `jsonrpc-process-connection'
 ;;;
 
 (defclass jsonrpc-process-connection (jsonrpc-connection)
diff --git a/lisp/kmacro.el b/lisp/kmacro.el
index 3a59708..3437dba 100644
--- a/lisp/kmacro.el
+++ b/lisp/kmacro.el
@@ -924,7 +924,7 @@ The ARG parameter is unused."
                  nil
                  (if kmacro-view-last-item
                      (concat (cond ((= kmacro-view-item-no 2) "2nd")
-                                   ((= kmacro-view-item-no 3) "3nd")
+                                   ((= kmacro-view-item-no 3) "3rd")
                                    (t (format "%dth" kmacro-view-item-no)))
                              " previous macro")
                    "Last macro")))
diff --git a/lisp/language/korea-util.el b/lisp/language/korea-util.el
index 296dbd7..3821785 100644
--- a/lisp/language/korea-util.el
+++ b/lisp/language/korea-util.el
@@ -46,7 +46,7 @@
      (concat "korean-hangul" default-korean-keyboard))))
 
 (defun quail-hangul-switch-symbol-ksc (&rest ignore)
-  "Swith to/from Korean symbol package."
+  "Switch to/from Korean symbol package."
   (interactive "i")
   (and current-input-method
        (if (string-equal current-input-method "korean-symbol")
@@ -55,7 +55,7 @@
         (activate-input-method "korean-symbol"))))
 
 (defun quail-hangul-switch-hanja (&rest ignore)
-  "Swith to/from Korean hanja package."
+  "Switch to/from Korean hanja package."
   (interactive "i")
   (and current-input-method
        (if (string-match "korean-hanja" current-input-method)
diff --git a/lisp/mh-e/mh-limit.el b/lisp/mh-e/mh-limit.el
index a3fbb89b..d457780 100644
--- a/lisp/mh-e/mh-limit.el
+++ b/lisp/mh-e/mh-limit.el
@@ -148,7 +148,7 @@ Use \\<mh-folder-mode-map>\\[mh-widen] to undo this 
command."
   "Put all following messages with same subject in sequence 'subject.
 If arg ALL is t, move to beginning of folder buffer to collect all
 messages.
-If arg ALL is nil, collect only messages fron current one on forward.
+If arg ALL is nil, collect only messages from current one on forward.
 
 Return number of messages put in the sequence:
 
@@ -198,7 +198,7 @@ It would be desirable to avoid hard-coding this.")
 
 This function only works with an unthreaded folder. If arg ALL is
 t, move to beginning of folder buffer to collect all messages. If
-arg ALL is nil, collect only messages fron current one on
+arg ALL is nil, collect only messages from current one on
 forward.
 
 Return number of messages put in the sequence:
diff --git a/lisp/mh-e/mh-speed.el b/lisp/mh-e/mh-speed.el
index 7e0981b..0732a16 100644
--- a/lisp/mh-e/mh-speed.el
+++ b/lisp/mh-e/mh-speed.el
@@ -307,7 +307,7 @@ The function will expand out parent folders of FOLDER if 
needed."
           (mh-speed-toggle))
         (goto-char (gethash prefix mh-speed-folder-map))))
     (while suffix-list
-      ;; We always need atleast one toggle. We need two if the directory list
+      ;; We always need at least one toggle. We need two if the directory list
       ;; is stale since a folder was added.
       (when (equal prefix (get-text-property (mh-line-beginning-position)
                                              'mh-folder))
diff --git a/lisp/net/tramp.el b/lisp/net/tramp.el
index 7fd48b2..6d44ad2 100644
--- a/lisp/net/tramp.el
+++ b/lisp/net/tramp.el
@@ -1297,7 +1297,7 @@ If nil, return `tramp-default-port'."
   (or (tramp-file-name-port vec)
       (tramp-get-method-parameter vec 'tramp-default-port)))
 
-;; Comparision of file names is performed by `tramp-equal-remote'.
+;; Comparison of file names is performed by `tramp-equal-remote'.
 (defun tramp-file-name-equal-p (vec1 vec2)
   "Check, whether VEC1 and VEC2 denote the same `tramp-file-name'."
   (and (tramp-file-name-p vec1) (tramp-file-name-p vec2)
@@ -4639,7 +4639,7 @@ If it doesn't exist, generate a new one."
   (with-tramp-connection-property (tramp-get-connection-process vec) "device"
     (cons -1 (setq tramp-devices (1+ tramp-devices)))))
 
-;; Comparision of vectors is performed by `tramp-file-name-equal-p'.
+;; Comparison of vectors is performed by `tramp-file-name-equal-p'.
 (defun tramp-equal-remote (file1 file2)
   "Check, whether the remote parts of FILE1 and FILE2 are identical.
 The check depends on method, user and host name of the files.  If
diff --git a/lisp/play/5x5.el b/lisp/play/5x5.el
index 7c4941e..3d4843a 100644
--- a/lisp/play/5x5.el
+++ b/lisp/play/5x5.el
@@ -582,7 +582,7 @@ Solutions are sorted from least to greatest Hamming weight."
               (math-sub dest org))))
 
           ;; transferm is the transfer matrix, ie it is the 25x25
-          ;; matrix applied everytime a flip is carried out where a
+          ;; matrix applied every time a flip is carried out where a
           ;; flip is defined by a 25x1 Dirac vector --- ie all zeros
           ;; but 1 in the position that is flipped.
           (transferm
diff --git a/lisp/progmodes/cc-engine.el b/lisp/progmodes/cc-engine.el
index 7d10027..4e336c0 100644
--- a/lisp/progmodes/cc-engine.el
+++ b/lisp/progmodes/cc-engine.el
@@ -2697,7 +2697,7 @@ comment at the start of cc-engine.el for more info."
   ;; or the car of the list is the "position element" of ELT, the position
   ;; where ELT is valid.
   ;;
-  ;; POINT is left at the postition for which the returned state is valid.  It
+  ;; POINT is left at the position for which the returned state is valid.  It
   ;; will be either the position element of ELT, or one character before
   ;; that.  (The latter happens in Emacs <= 25 and XEmacs, when ELT indicates
   ;; its position element directly follows a potential first character of a
@@ -2767,7 +2767,7 @@ comment at the start of cc-engine.el for more info."
              ((nth 3 state)            ; A string
               (list (point) (nth 3 state) (nth 8 state)))
              ((and (nth 4 state)                ; A comment
-                   (not (eq (nth 7 state) 'syntax-table))) ; but not a psuedo 
comment.
+                   (not (eq (nth 7 state) 'syntax-table))) ; but not a pseudo 
comment.
               (list (point)
                     (if (eq (nth 7 state) 1) 'c++ 'c)
                     (nth 8 state)))
@@ -2894,7 +2894,7 @@ comment at the start of cc-engine.el for more info."
        (setq nc-list (cdr nc-list))))))
 
 (defun c-semi-get-near-cache-entry (here)
-  ;; Return the near cache entry at the highest postion before HERE, if any,
+  ;; Return the near cache entry at the highest position before HERE, if any,
   ;; or nil.  The near cache entry is of the form (POSITION . STATE), where
   ;; STATE has the form of a result of `parse-partial-sexp'.
   (let ((nc-pos-state
@@ -7170,7 +7170,7 @@ comment at the start of cc-engine.el for more info."
   ;; characters.)  If the raw string is not terminated, E\) and E\" are set to
   ;; nil.
   ;;
-  ;; Note: this function is dependant upon the correct syntax-table text
+  ;; Note: this function is dependent upon the correct syntax-table text
   ;; properties being set.
   (let ((state (c-semi-pp-to-literal (point)))
        open-quote-pos open-paren-pos close-paren-pos close-quote-pos id)
diff --git a/lisp/progmodes/cperl-mode.el b/lisp/progmodes/cperl-mode.el
index d35eab1..468ffc9 100644
--- a/lisp/progmodes/cperl-mode.el
+++ b/lisp/progmodes/cperl-mode.el
@@ -814,7 +814,7 @@ capable syntax engines).
 
 (defvar cperl-speed 'please-ignore-this-line
   "This is an incomplete compendium of what is available in other parts
-of CPerl documentation.  (Please inform me if I skept anything.)
+of CPerl documentation.  (Please inform me if I skipped anything.)
 
 There is a perception that CPerl is slower than alternatives.  This part
 of documentation is designed to overcome this misconception.
@@ -4486,7 +4486,7 @@ the sections using `cperl-pod-head-face', 
`cperl-pod-face',
                                       'syntax-table cperl-st-cfence))))
                              (setq was-subgr nil))
                             (t         ; (?#)-comment
-                             ;; Inside "(" and "\" arn't special in any way
+                             ;; Inside "(" and "\" aren't special in any way
                              ;; Works also if the outside delimiters are ().
                              (or;;(if (eq (char-after b) ?\) )
                               ;;(re-search-forward
diff --git a/lisp/progmodes/elisp-mode.el b/lisp/progmodes/elisp-mode.el
index 72b94a5..b480368 100644
--- a/lisp/progmodes/elisp-mode.el
+++ b/lisp/progmodes/elisp-mode.el
@@ -683,7 +683,7 @@ otherwise build the summary from TYPE and SYMBOL."
   "List of functions to be run from `elisp--xref-find-definitions' to add 
additional xrefs.
 Called with one arg; the symbol whose definition is desired.
 Each function should return a list of xrefs, or nil; the first
-non-nil result supercedes the xrefs produced by
+non-nil result supersedes the xrefs produced by
 `elisp--xref-find-definitions'.")
 
 (cl-defmethod xref-backend-definitions ((_backend (eql elisp)) identifier)
diff --git a/lisp/progmodes/etags.el b/lisp/progmodes/etags.el
index 2c5c365..f6af1f2 100644
--- a/lisp/progmodes/etags.el
+++ b/lisp/progmodes/etags.el
@@ -1845,7 +1845,7 @@ Also see the documentation of the `tags-file-name' 
variable."
 Third arg DELIMITED (prefix arg) means replace only word-delimited matches.
 If you exit (\\[keyboard-quit], RET or q), you can resume the query replace
 with the command \\[tags-loop-continue].
-For non-interactive use, superceded by `fileloop-initialize-replace'."
+For non-interactive use, superseded by `fileloop-initialize-replace'."
   (declare (advertised-calling-convention (from to &optional delimited) 
"27.1"))
   (interactive (query-replace-read-args "Tags query replace (regexp)" t t))
   (fileloop-initialize-replace
diff --git a/lisp/progmodes/flymake.el b/lisp/progmodes/flymake.el
index bdb7757..b286208 100644
--- a/lisp/progmodes/flymake.el
+++ b/lisp/progmodes/flymake.el
@@ -226,10 +226,10 @@ Specifically, start it when the saved buffer is actually 
displayed."
 (defcustom flymake-suppress-zero-counters :warning
   "Control appearance of zero-valued diagnostic counters in mode line.
 
-If set to t, supress all zero counters.  If set to a severity
+If set to t, suppress all zero counters.  If set to a severity
 symbol like `:warning' (the default) suppress zero counters less
 severe than that severity, according to `warning-numeric-level'.
-If set to nil, don't supress any zero counters."
+If set to nil, don't suppress any zero counters."
   :type 'symbol)
 
 (when (fboundp 'define-fringe-bitmap)
@@ -632,7 +632,7 @@ associated `flymake-category' return DEFAULT."
      for (ov-prop . value) in
      (append (reverse
               (flymake--diag-overlay-properties diagnostic))
-             (reverse ; ensure ealier props override later ones
+             (reverse ; ensure earlier props override later ones
               (flymake--lookup-type-property type 'flymake-overlay-control))
              (alist-get type flymake-diagnostic-types-alist))
      do (overlay-put ov ov-prop value))
@@ -1004,7 +1004,7 @@ special *Flymake log* buffer."  :group 'flymake :lighter
     (add-hook 'kill-buffer-hook 'flymake-kill-buffer-hook nil t)
     (add-hook 'eldoc-documentation-functions 'flymake-eldoc-function t t)
 
-    ;; If Flymake happened to be alrady already ON, we must cleanup
+    ;; If Flymake happened to be already already ON, we must cleanup
     ;; existing diagnostic overlays, lest we forget them by blindly
     ;; reinitializing `flymake--backend-state' in the next line.
     ;; See https://github.com/joaotavora/eglot/issues/223.
diff --git a/lisp/progmodes/gdb-mi.el b/lisp/progmodes/gdb-mi.el
index e5c62f9..8d6f8af 100644
--- a/lisp/progmodes/gdb-mi.el
+++ b/lisp/progmodes/gdb-mi.el
@@ -2547,7 +2547,7 @@ file names include non-ASCII characters."
 
 (defun gdb-gdb (_output-field)
   ;; This is needed because the "explore" command is not ended by the
-  ;; likes of "end" or "quit", but instead by a RET at the approriate
+  ;; likes of "end" or "quit", but instead by a RET at the appropriate
   ;; place, and we know we have exited "explore" when we get the
   ;; "(gdb)" prompt.
   (and (> gdb-control-level 0)
diff --git a/lisp/progmodes/make-mode.el b/lisp/progmodes/make-mode.el
index 235279e..01cc330 100644
--- a/lisp/progmodes/make-mode.el
+++ b/lisp/progmodes/make-mode.el
@@ -1413,7 +1413,7 @@ Fill comments, backslashed lines, and variable 
definitions specially."
   "Leave the browser and return to the makefile buffer."
   (interactive)
   (let ((my-client makefile-browser-client))
-    (setq makefile-browser-client nil) ; we quitted, so NO client!
+    (setq makefile-browser-client nil) ; we quit, so NO client!
     (set-buffer-modified-p nil)
     (quit-window t)
     (pop-to-buffer my-client)))
diff --git a/lisp/progmodes/project.el b/lisp/progmodes/project.el
index 3912045..8c550b5 100644
--- a/lisp/progmodes/project.el
+++ b/lisp/progmodes/project.el
@@ -1030,7 +1030,7 @@ Each condition is either:
   * `or': the cdr is a list of recursive conditions, of which at
     least one has to be met.
 
-If any of these conditions are satified for a buffer in the
+If any of these conditions are satisfied for a buffer in the
 current project, it will be killed."
   :type '(repeat (choice regexp function symbol
                          (cons :tag "Major mode"
@@ -1225,7 +1225,7 @@ command to run when KEY is pressed.  LABEL is used to 
distinguish
 the menu entries in the dispatch menu.")
 
 (defun project--keymap-prompt ()
-  "Return a prompt for the project swithing dispatch menu."
+  "Return a prompt for the project switching dispatch menu."
   (mapconcat
    (pcase-lambda (`(,key ,label))
      (format "[%s] %s"
diff --git a/lisp/progmodes/python.el b/lisp/progmodes/python.el
index d2eb5f2..7c3b611 100644
--- a/lisp/progmodes/python.el
+++ b/lisp/progmodes/python.el
@@ -2059,7 +2059,7 @@ that they are prioritized when looking for executables."
 When this variable is non-nil, values are exported into remote
 hosts PATH before starting processes.  Values defined in
 `python-shell-exec-path' will take precedence to paths defined
-here.  Normally you wont use this variable directly unless you
+here.  Normally you won't use this variable directly unless you
 plan to ensure a particular set of paths to all Python shell
 executed through tramp connections."
   :version "25.1"
@@ -4130,7 +4130,7 @@ JUSTIFY should be used (if applicable) as in 
`fill-paragraph'."
                 (goto-char (point-max)))
             (point-marker)))
          (multi-line-p
-          ;; Docstring styles may vary for oneliners and multi-liners.
+          ;; Docstring styles may vary for one-liners and multi-liners.
           (> (count-matches "\n" str-start-pos str-end-pos) 0))
          (delimiters-style
           (pcase python-fill-docstring-style
@@ -5336,7 +5336,7 @@ To use `flake8' you would set this to (\"flake8\" \"-\")."
   :group 'python-flymake
   :type '(repeat string))
 
-;; The default regexp accomodates for older pyflakes, which did not
+;; The default regexp accommodates for older pyflakes, which did not
 ;; report the column number, and at the same time it's compatible with
 ;; flake8 output, although it may be redefined to explicitly match the
 ;; TYPE
@@ -5536,7 +5536,7 @@ REPORT-FN is Flymake's callback function."
          (^ '(- (1+ (current-indentation))))))
 
   (with-no-warnings
-    ;; supress warnings about eldoc-documentation-function being obsolete
+    ;; suppress warnings about eldoc-documentation-function being obsolete
    (if (null eldoc-documentation-function)
        ;; Emacs<25
        (set (make-local-variable 'eldoc-documentation-function)
diff --git a/lisp/progmodes/verilog-mode.el b/lisp/progmodes/verilog-mode.el
index 5a469bb..b1abefe 100644
--- a/lisp/progmodes/verilog-mode.el
+++ b/lisp/progmodes/verilog-mode.el
@@ -1284,7 +1284,7 @@ won't merge conflict."
 
 (defcustom verilog-auto-inst-template-required nil
   "If non-nil, when creating a port with AUTOINST, require a template.
-Any port which does not have a template will be ommitted from the
+Any port which does not have a template will be omitted from the
 instantiation.
 
 If nil, if a port is not templated it will be inserted to connect
diff --git a/lisp/replace.el b/lisp/replace.el
index dc6e67f..035031a 100644
--- a/lisp/replace.el
+++ b/lisp/replace.el
@@ -1674,7 +1674,7 @@ See also `multi-occur'."
 
     (with-current-buffer occur-buf
       ;; Make the default-directory of the *Occur* buffer match that of
-      ;; the buffer where the occurences come from
+      ;; the buffer where the occurrences come from
       (setq default-directory source-buffer-default-directory)
       (if (stringp nlines)
          (fundamental-mode) ;; This is for collect operation.
diff --git a/lisp/so-long.el b/lisp/so-long.el
index f8a5cc9..6ae8d0a 100644
--- a/lisp/so-long.el
+++ b/lisp/so-long.el
@@ -833,7 +833,7 @@ available in Emacs versions < 27).  For more information 
refer to info node
 `(emacs) Bidirectional Editing' and info node `(elisp) Bidirectional Display'.
 
 Buffers are made read-only by default to prevent potentially-slow editing from
-occurring inadvertantly, as buffers with excessively long lines are likely not
+occurring inadvertently, as buffers with excessively long lines are likely not
 intended to be edited manually."
   :type '(alist :key-type (variable :tag "Variable")
                 :value-type (sexp :tag "Value"))
diff --git a/lisp/subr.el b/lisp/subr.el
index f00e4ef..377d914 100644
--- a/lisp/subr.el
+++ b/lisp/subr.el
@@ -4452,7 +4452,7 @@ This function returns a freshly created string."
                 ;; We didn't have a match after all.
                 (setq i (1+ i))
               ;; We had one, so gather the previous part and the
-              ;; substition.
+              ;; substitution.
               (when (not (= start i))
                 (push (substring instring start i) result))
               (push tostring result)
diff --git a/lisp/wid-browse.el b/lisp/wid-browse.el
index 097e769..53f918c 100644
--- a/lisp/wid-browse.el
+++ b/lisp/wid-browse.el
@@ -187,7 +187,7 @@ if that value is non-nil."
 
 (define-widget 'widget-browse 'push-button
   "Button for creating a widget browser.
-The :value of the widget shuld be the widget to be browsed."
+The :value of the widget should be the widget to be browsed."
   :format "%[[%v]%]"
   :value-create 'widget-browse-value-create
   :action 'widget-browse-action)
diff --git a/lisp/xwidget.el b/lisp/xwidget.el
index e5c1b47..caf57ae 100644
--- a/lisp/xwidget.el
+++ b/lisp/xwidget.el
@@ -217,7 +217,7 @@ If N is omitted or nil, scroll down by one line."
 (defun xwidget-webkit-scroll-forward (&optional n)
   "Scroll webkit horizontally by N chars.
 The width of char is calculated with `window-font-width'.
-If N is ommited or nil, scroll forwards by one char."
+If N is omitted or nil, scroll forwards by one char."
   (interactive "p")
   (xwidget-webkit-execute-script
    (xwidget-webkit-current-session)
@@ -227,7 +227,7 @@ If N is ommited or nil, scroll forwards by one char."
 (defun xwidget-webkit-scroll-backward (&optional n)
   "Scroll webkit back by N chars.
 The width of char is calculated with `window-font-width'.
-If N is ommited or nil, scroll backwards by one char."
+If N is omitted or nil, scroll backwards by one char."
   (interactive "p")
   (xwidget-webkit-execute-script
    (xwidget-webkit-current-session)
diff --git a/src/dispextern.h b/src/dispextern.h
index e20f7bb..0d982f7 100644
--- a/src/dispextern.h
+++ b/src/dispextern.h
@@ -102,7 +102,7 @@ typedef XImage *Emacs_Pix_Context;
 #endif
 
 #ifdef USE_CAIRO
-/* Mininal version of XImage.  */
+/* Minimal version of XImage.  */
 typedef struct
 {
   int width, height;           /* size of image */
diff --git a/src/keyboard.c b/src/keyboard.c
index 8525d3b..af075a4 100644
--- a/src/keyboard.c
+++ b/src/keyboard.c
@@ -5696,7 +5696,7 @@ make_lispy_event (struct input_event *event)
            ignore_mouse_drag_p = false;
          }
 
-       /* Now we're releasing a button - check the co-ordinates to
+       /* Now we're releasing a button - check the coordinates to
            see if this was a click or a drag.  */
        else if (event->modifiers & up_modifier)
          {
@@ -6644,7 +6644,7 @@ has the same base event type and all the specified 
modifiers.  */)
 DEFUN ("internal-handle-focus-in", Finternal_handle_focus_in,
        Sinternal_handle_focus_in, 1, 1, 0,
        doc: /* Internally handle focus-in events.
-This function potentially generates an artifical switch-frame event.  */)
+This function potentially generates an artificial switch-frame event.  */)
      (Lisp_Object event)
 {
   Lisp_Object frame;
diff --git a/src/nsxwidget.m b/src/nsxwidget.m
index 2910d97..3c6402c 100644
--- a/src/nsxwidget.m
+++ b/src/nsxwidget.m
@@ -36,7 +36,7 @@ along with GNU Emacs.  If not, see 
<http://www.gnu.org/licenses/>.  */
    rendering techniques, which is used by GTK xwidget implementation;
    Specifically NSView level view sharing / copying is not working.
 
-   *** So only one view can be associcated with a model. ***
+   *** So only one view can be associated with a model. ***
 
    With this decision, implementation is plain and can expect best out
    of webkit2's rationale.  But process and session structures will
diff --git a/src/pdumper.c b/src/pdumper.c
index 217ffa6..9099004 100644
--- a/src/pdumper.c
+++ b/src/pdumper.c
@@ -1817,7 +1817,7 @@ dump_field_lv_or_rawptr (struct dump_context *ctx,
 
   /* Now value is the Lisp_Object to which we want to point whether or
      not the field is a raw pointer (in which case we just synthesized
-     the Lisp_Object outselves) or a Lisp_Object (in which case we
+     the Lisp_Object ourselves) or a Lisp_Object (in which case we
      just copied the thing).  Add a fixup or relocation.  */
 
   intptr_t out_value;
@@ -1908,7 +1908,7 @@ dump_field_fixup_later (struct dump_context *ctx,
   (void) field_relpos (in_start, in_field);
 }
 
-/* Mark an output object field, which is as wide as a poiner, as being
+/* Mark an output object field, which is as wide as a pointer, as being
    fixed up to point to a specific offset in the dump.  */
 static void
 dump_field_ptr_to_dump_offset (struct dump_context *ctx,
diff --git a/src/term.c b/src/term.c
index 3f52858..3677644 100644
--- a/src/term.c
+++ b/src/term.c
@@ -2416,7 +2416,7 @@ tty_draw_row_with_mouse_face (struct window *w, struct 
glyph_row *row,
   pos_y = row->y + WINDOW_TOP_EDGE_Y (w);
   pos_x = row->used[LEFT_MARGIN_AREA] + start_hpos + WINDOW_LEFT_EDGE_X (w);
 
-  /* Save current cursor co-ordinates.  */
+  /* Save current cursor coordinates.  */
   save_y = curY (tty);
   save_x = curX (tty);
   cursor_to (f, pos_y, pos_x);
diff --git a/src/w32fns.c b/src/w32fns.c
index ab86433..3134f67 100644
--- a/src/w32fns.c
+++ b/src/w32fns.c
@@ -3640,7 +3640,7 @@ get_wm_chars (HWND aWnd, int *buf, int buflen, int 
ignore_ctrl, int ctrl,
    non-Emacs window with the same language environment, and using (dead)keys
    there would change the value stored in the kernel, but not this value.  */
 /* A layout may emit deadkey=0.  It looks like this would reset the state
-   of the kernel's finite automaton (equivalent to emiting 0-length string,
+   of the kernel's finite automaton (equivalent to emitting 0-length string,
    which is otherwise impossible in the dead-key map of a layout).
    Be ready to treat the case when this delivers WM_(SYS)DEADCHAR. */
 static int after_deadkey = -1;
@@ -3701,7 +3701,7 @@ deliver_wm_chars (int do_translate, HWND hwnd, UINT msg, 
UINT wParam,
         of w32_get_key_modifiers ().  */
       wmsg.dwModifiers = w32_kbd_mods_to_emacs (console_modifiers, wParam);
 
-      /* What follows is just heuristics; the correct treatement requires
+      /* What follows is just heuristics; the correct treatment requires
         non-destructive ToUnicode():
           
http://search.cpan.org/~ilyaz/UI-KeyboardLayout/lib/UI/KeyboardLayout.pm#Can_an_application_on_Windows_accept_keyboard_events?_Part_IV:_application-specific_modifiers
 
@@ -7001,7 +7001,7 @@ w32_create_tip_frame (struct w32_display_info *dpyinfo, 
Lisp_Object parms)
      Frame parameters may be changed if .Xdefaults contains
      specifications for the default font.  For example, if there is an
      `Emacs.default.attributeBackground: pink', the `background-color'
-     attribute of the frame get's set, which let's the internal border
+     attribute of the frame gets set, which let's the internal border
      of the tooltip frame appear in pink.  Prevent this.  */
   {
     Lisp_Object bg = Fframe_parameter (frame, Qbackground_color);
@@ -7085,7 +7085,7 @@ compute_tip_xy (struct frame *f,
 
       /* If multiple monitor support is available, constrain the tip onto
         the current monitor. This improves the above by allowing negative
-        co-ordinates if monitor positions are such that they are valid, and
+        coordinates if monitor positions are such that they are valid, and
         snaps a tooltip onto a single monitor if we are close to the edge
         where it would otherwise flow onto the other monitor (or into
         nothingness if there is a gap in the overlap).  */
@@ -8079,7 +8079,7 @@ operations:
  \"pastelink\"
           - create a shortcut in DOCUMENT (which must be a directory)
               the file or directory whose name is in the clipboard.
- \"runas\"   - run DOCUMENT, which must be an excutable file, with
+ \"runas\"   - run DOCUMENT, which must be an executable file, with
               elevated privileges (a.k.a. \"as Administrator\").
  \"properties\"
           - open the property sheet dialog for DOCUMENT.
diff --git a/src/w32heap.c b/src/w32heap.c
index ececc73..ba3550b 100644
--- a/src/w32heap.c
+++ b/src/w32heap.c
@@ -884,7 +884,7 @@ setrlimit (rlimit_resource_t rltype, const struct rlimit 
*rlp)
     {
     case RLIMIT_STACK:
     case RLIMIT_NOFILE:
-      /* We cannot modfy these limits, so we always fail.  */
+      /* We cannot modify these limits, so we always fail.  */
       errno = EPERM;
       break;
     default:
diff --git a/src/w32menu.c b/src/w32menu.c
index e076043..da2db78 100644
--- a/src/w32menu.c
+++ b/src/w32menu.c
@@ -1485,7 +1485,7 @@ w32_menu_display_help (HWND owner, HMENU menu, UINT item, 
UINT flags)
             crash Emacs when we try to display those "strings".  It
             is unclear why we get these dwItemData, or what they are:
             sometimes they point to a wchar_t string that is the menu
-            title, sometimes to someting that doesn't look like text
+            title, sometimes to something that doesn't look like text
             at all.  (The problematic data also comes with the 0x0800
             bit set, but this bit is not documented, so we don't want
             to depend on it.)  */
diff --git a/src/w32term.c b/src/w32term.c
index 2669f29..e0618e4 100644
--- a/src/w32term.c
+++ b/src/w32term.c
@@ -6877,7 +6877,7 @@ w32_make_frame_visible (struct frame *f)
       /* According to a report in emacs-devel 2008-06-03, SW_SHOWNORMAL
         causes unexpected behavior when unminimizing frames that were
         previously maximized.  But only SW_SHOWNORMAL works properly for
-        frames that were truely hidden (using make-frame-invisible), so
+        frames that were truly hidden (using make-frame-invisible), so
         we need it to avoid Bug#5482.  It seems that iconified is only
         set for minimized windows that are still visible, so use that to
         determine the appropriate flag to pass ShowWindow.  */
diff --git a/src/w32term.h b/src/w32term.h
index 8ba2480..694493c 100644
--- a/src/w32term.h
+++ b/src/w32term.h
@@ -476,7 +476,7 @@ struct scroll_bar {
      editing large files, we establish a minimum height by always
      drawing handle bottoms VERTICAL_SCROLL_BAR_MIN_HANDLE pixels below
      where they would be normally; the bottom and top are in a
-     different co-ordinate system.  */
+     different coordinate system.  */
   int start, end;
 
   /* If the scroll bar handle is currently being dragged by the user,
diff --git a/src/xdisp.c b/src/xdisp.c
index 49225c5..ac5307f 100644
--- a/src/xdisp.c
+++ b/src/xdisp.c
@@ -510,7 +510,7 @@ static Lisp_Object list_of_error;
               || *BYTE_POS_ADDR (IT_BYTEPOS (*it)) == '\t'))))
 
 /* These are the category sets we use.  They are defined by
-   kinsoku.el and chracters.el.  */
+   kinsoku.el and characters.el.  */
 #define NOT_AT_EOL '<'
 #define NOT_AT_BOL '>'
 #define LINE_BREAKABLE '|'
@@ -2230,7 +2230,7 @@ estimate_mode_line_height (struct frame *f, enum face_id 
face_id)
 }
 
 /* Given a pixel position (PIX_X, PIX_Y) on frame F, return glyph
-   co-ordinates in (*X, *Y).  Set *BOUNDS to the rectangle that the
+   coordinates in (*X, *Y).  Set *BOUNDS to the rectangle that the
    glyph at X, Y occupies, if BOUNDS != 0.  If NOCLIP, do
    not force the value into range.  */
 
@@ -3744,7 +3744,7 @@ init_to_row_end (struct it *it, struct window *w, struct 
glyph_row *row)
        it->continuation_lines_width
          = row->continuation_lines_width + row->pixel_width;
       CHECK_IT (it);
-      /* Initializing IT in the presense of compositions in reordered
+      /* Initializing IT in the presence of compositions in reordered
         rows is tricky: row->end above will generally cause us to
         start at position that is not the first one in the logical
         order, and we might therefore miss the composition earlier in
diff --git a/src/xfns.c b/src/xfns.c
index 78f977b..46e4bd7 100644
--- a/src/xfns.c
+++ b/src/xfns.c
@@ -6535,7 +6535,7 @@ x_create_tip_frame (struct x_display_info *dpyinfo, 
Lisp_Object parms)
      Frame parameters may be changed if .Xdefaults contains
      specifications for the default font.  For example, if there is an
      `Emacs.default.attributeBackground: pink', the `background-color'
-     attribute of the frame get's set, which let's the internal border
+     attribute of the frame gets set, which let's the internal border
      of the tooltip frame appear in pink.  Prevent this.  */
   {
     Lisp_Object bg = Fframe_parameter (frame, Qbackground_color);
diff --git a/src/xterm.h b/src/xterm.h
index db8d584..0f8ba5e 100644
--- a/src/xterm.h
+++ b/src/xterm.h
@@ -890,7 +890,7 @@ struct scroll_bar
      editing large files, we establish a minimum height by always
      drawing handle bottoms VERTICAL_SCROLL_BAR_MIN_HANDLE pixels below
      where they would be normally; the bottom and top are in a
-     different co-ordinate system.  */
+     different coordinate system.  */
   int start, end;
 
   /* If the scroll bar handle is currently being dragged by the user,
diff --git a/test/lisp/dired-aux-tests.el b/test/lisp/dired-aux-tests.el
index 54ec5d6..6bb8ced 100644
--- a/test/lisp/dired-aux-tests.el
+++ b/test/lisp/dired-aux-tests.el
@@ -40,7 +40,7 @@
           (should-not (dired-do-shell-command "ls ? ./`?`" nil files)))
       (delete-file foo))))
 
-;; Auxiliar macro for `dired-test-bug28834': it binds
+;; Auxiliary macro for `dired-test-bug28834': it binds
 ;; `dired-create-destination-dirs' to CREATE-DIRS and execute BODY.
 ;; If YES-OR-NO is non-nil, it binds `yes-or-no-p' to
 ;; to avoid the prompt.
diff --git a/test/lisp/emacs-lisp/faceup-resources/faceup-test-mode.el 
b/test/lisp/emacs-lisp/faceup-resources/faceup-test-mode.el
index 4bad360..c77f2dc 100644
--- a/test/lisp/emacs-lisp/faceup-resources/faceup-test-mode.el
+++ b/test/lisp/emacs-lisp/faceup-resources/faceup-test-mode.el
@@ -44,7 +44,7 @@
      (0 (progn
           (add-text-properties (match-beginning 0)
                                (match-end 0)
-                               '(help-echo "Baloon tip: Fly smoothly!"))
+                               '(help-echo "Balloon tip: Fly smoothly!"))
           font-lock-warning-face))))
   "Highlight rules for `faceup-test-mode'.")
 
diff --git a/test/lisp/emacs-lisp/lisp-mode-tests.el 
b/test/lisp/emacs-lisp/lisp-mode-tests.el
index febac8f..b1b7847 100644
--- a/test/lisp/emacs-lisp/lisp-mode-tests.el
+++ b/test/lisp/emacs-lisp/lisp-mode-tests.el
@@ -153,7 +153,7 @@ noindent\" 3
       (should (equal (buffer-string) str)))))
 
 (ert-deftest indent-sexp-stop-before-eol-non-lisp ()
-  "`indent-sexp' shouldn't be too agressive in non-Lisp modes."
+  "`indent-sexp' shouldn't be too aggressive in non-Lisp modes."
   ;; See https://debbugs.gnu.org/35286#13.
   (with-temp-buffer
     (prolog-mode)
diff --git a/test/lisp/gnus/mml-sec-tests.el b/test/lisp/gnus/mml-sec-tests.el
index ba0783b..4c745ea 100644
--- a/test/lisp/gnus/mml-sec-tests.el
+++ b/test/lisp/gnus/mml-sec-tests.el
@@ -828,7 +828,7 @@ In the first decryption this passphrase is hardcoded, in 
the second one it
        method "uid1@example.org" "sub@example.org" nil
        ;; Beware!  For passphrases copy-sequence is necessary, as they may
        ;; be erased, which actually changes the function's code and causes
-       ;; multiple invokations to fail.  I was surprised...
+       ;; multiple invocations to fail.  I was surprised...
        (copy-sequence "Passphrase") t)
        (mml-secure-test-en-decrypt-with-passphrase
        method "uid1@example.org" "sub@example.org" nil
diff --git a/test/lisp/jsonrpc-tests.el b/test/lisp/jsonrpc-tests.el
index 168a2c9..1ef83da 100644
--- a/test/lisp/jsonrpc-tests.el
+++ b/test/lisp/jsonrpc-tests.el
@@ -167,7 +167,7 @@
 
 (ert-deftest deferred-action-toolate ()
   :tags '(:expensive-test)
-  "Deferred request fails because noone clears the flag."
+  "Deferred request fails because no one clears the flag."
   (jsonrpc--with-emacsrpc-fixture (conn)
     (should-error
      (jsonrpc-request conn '+ [1 2]
diff --git a/test/manual/etags/c-src/emacs/src/keyboard.c 
b/test/manual/etags/c-src/emacs/src/keyboard.c
index d4e3848..e869363 100644
--- a/test/manual/etags/c-src/emacs/src/keyboard.c
+++ b/test/manual/etags/c-src/emacs/src/keyboard.c
@@ -5754,7 +5754,7 @@ make_lispy_event (struct input_event *event)
            ignore_mouse_drag_p = 0;
          }
 
-       /* Now we're releasing a button - check the co-ordinates to
+       /* Now we're releasing a button - check the coordinates to
            see if this was a click or a drag.  */
        else if (event->modifiers & up_modifier)
          {
diff --git a/test/manual/etags/y-src/parse.c b/test/manual/etags/y-src/parse.c
index e35d862..0415c4a 100644
--- a/test/manual/etags/y-src/parse.c
+++ b/test/manual/etags/y-src/parse.c
@@ -1917,7 +1917,7 @@ yylex FUN0()
                        }
 #ifdef TEST
                        if(nn==n_usr_funs) {
-                               io_error_msg("Couln't turn fp into a ##");
+                               io_error_msg("Couldn't turn fp into a ##");
                                parse_error=BAD_FUNC;
                                return ERROR;
                        }



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/progmodes/hideif.el b/lisp/progmodes/hideif.el
index 0b1ba80..9177b13 100644
--- a/lisp/progmodes/hideif.el
+++ b/lisp/progmodes/hideif.el
@@ -301,7 +301,7 @@ Several variables affect how the hiding is done:
         ;; `hide-ifdef-env' is now a global variable.
         ;; We can still simulate the behavior of older hideif versions (i.e.
         ;; `hide-ifdef-env' being buffer local) by clearing this variable
         ;; (C-c @ C) everytime before hiding current buffer.
 ;;      (set (make-local-variable 'hide-ifdef-env)
 ;;           (default-value 'hide-ifdef-env))
         (set 'hide-ifdef-env (default-value 'hide-ifdef-env))
@@ -1490,7 +1490,7 @@ Refer to `hide-ifdef-expand-reinclusion-protection' for 
more details."
          (test (hif-canonicalize hif-ifx-regexp))
          (range (hif-find-range))
          (elifs (hif-range-elif range))
-         (if-part t) ; Everytime we start from if-part
+         (if-part t) ; Every time we start from if-part
          (complete nil))
     ;; (message "test = %s" test) (sit-for 1)
 
@@ -1650,7 +1650,7 @@ first arg will be `hif-etc'."
 ;; postponed the evaluation process one stage and store the "parsed tree"
 ;; into symbol database. The evaluation process was then "strings -> tokens
 ;; -> [parsed tree] -> value". Hideif therefore run slower since it need to
 ;; evaluate the parsed tree everytime when trying to expand the symbol. These
 ;; temporarily code changes are obsolete and not in Emacs source repository.
 ;;
 ;; Furthermore, CPP did allow partial expression to be defined in several
@@ -1659,7 +1659,7 @@ first arg will be `hif-etc'."
 ;; further, otherwise those partial expression will be fail on parsing and
 ;; we'll miss all macros that reference it. The evaluation process thus
 ;; became "strings -> [tokens] -> parsed tree -> value." This degraded the
 ;; performance since we need to parse tokens and evaluate them everytime
 ;; when that symbol is referenced.
 ;;
 ;; In real cases I found a lot portion of macros are "simple macros" that
@@ -301,7 +301,7 @@ Several variables affect how the hiding is done:
         ;; We can still simulate the behavior of older hideif versions (i.e.
         ;; `hide-ifdef-env' being buffer local) by clearing this variable
-        ;; (C-c @ C) everytime before hiding current buffer.
+        ;; (C-c @ C) every time before hiding current buffer.
 ;;      (set (make-local-variable 'hide-ifdef-env)
 ;;           (default-value 'hide-ifdef-env))
@@ -1650,7 +1650,7 @@ first arg will be `hif-etc'."
 ;; into symbol database. The evaluation process was then "strings -> tokens
 ;; -> [parsed tree] -> value". Hideif therefore run slower since it need to
-;; evaluate the parsed tree everytime when trying to expand the symbol. These
+;; evaluate the parsed tree every time when trying to expand the symbol. These
 ;; temporarily code changes are obsolete and not in Emacs source repository.
 ;;
@@ -1659,7 +1659,7 @@ first arg will be `hif-etc'."
 ;; we'll miss all macros that reference it. The evaluation process thus
 ;; became "strings -> [tokens] -> parsed tree -> value." This degraded the
-;; performance since we need to parse tokens and evaluate them everytime
+;; performance since we need to parse tokens and evaluate them every time
 ;; when that symbol is referenced.
 ;;
diff --git a/lisp/ses.el b/lisp/ses.el
index a2e6033..64d03a7 100644
--- a/lisp/ses.el
+++ b/lisp/ses.el
@@ -3672,7 +3672,7 @@ highlighted range in the spreadsheet."
     ;; 'rowcol' corresponding to 'ses-cell' property of symbol
     ;; 'sym'. Both must be the same.
     (unless (eq sym old-name)
-      (error "Spreadsheet is broken, both symbols %S and %S refering to cell 
(%d,%d)" sym old-name row col))
+      (error "Spreadsheet is broken, both symbols %S and %S referring to cell 
(%d,%d)" sym old-name row col))
     (if new-rowcol
         ;; the new name is of A1 type, so we test that the coordinate
         ;; inferred from new name
@@ -3685,7 +3685,7 @@ highlighted range in the spreadsheet."
       (puthash new-name rowcol ses--named-cell-hashmap))
     (push `(ses-rename-cell ,old-name ,cell) buffer-undo-list)
     (cl-pushnew rowcol ses--deferred-write :test #'equal)
     ;; Replace name by new name in formula of cells refering to renamed cell.
     (dolist (ref (ses-cell-references cell))
       (let* ((x (ses-sym-rowcol ref))
             (xcell  (ses-get-cell (car x) (cdr x))))
@@ -3685,7 +3685,7 @@ highlighted range in the spreadsheet."
     (push `(ses-rename-cell ,old-name ,cell) buffer-undo-list)
     (cl-pushnew rowcol ses--deferred-write :test #'equal)
-    ;; Replace name by new name in formula of cells refering to renamed cell.
+    ;; Replace name by new name in formula of cells referring to renamed cell.
     (dolist (ref (ses-cell-references cell))
       (let* ((x (ses-sym-rowcol ref))